==> openshift-model-operatorhub-5.7.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class InstallPlanSpecBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecBuilder>{
  public InstallPlanSpecBuilder() {
    this(false);
  }
  public InstallPlanSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new InstallPlanSpec(), validationEnabled);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new InstallPlanSpec(), validationEnabled);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance) {
    this(fluent, instance, false);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApproval(instance.getApproval()); 
    fluent.withApproved(instance.getApproved()); 
    fluent.withClusterServiceVersionNames(instance.getClusterServiceVersionNames()); 
    fluent.withGeneration(instance.getGeneration()); 
    fluent.withSource(instance.getSource()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    this.validationEnabled = validationEnabled; 
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance) {
    this(instance,false);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApproval(instance.getApproval()); 
    this.withApproved(instance.getApproved()); 
    this.withClusterServiceVersionNames(instance.getClusterServiceVersionNames()); 
    this.withGeneration(instance.getGeneration()); 
    this.withSource(instance.getSource()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec build() {
    InstallPlanSpec buildable = new InstallPlanSpec(fluent.getApproval(),fluent.getApproved(),fluent.getClusterServiceVersionNames(),fluent.getGeneration(),fluent.getSource(),fluent.getSourceNamespace());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    InstallPlanSpecBuilder that = (InstallPlanSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class InstallPlanSpecBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecBuilder>{
  public InstallPlanSpecBuilder() {
    this(false);
  }
  public InstallPlanSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new InstallPlanSpec(), validationEnabled);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new InstallPlanSpec(), validationEnabled);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance) {
    this(fluent, instance, false);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApproval(instance.getApproval()); 
    fluent.withApproved(instance.getApproved()); 
    fluent.withClusterServiceVersionNames(instance.getClusterServiceVersionNames()); 
    fluent.withGeneration(instance.getGeneration()); 
    fluent.withSource(instance.getSource()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance) {
    this(instance,false);
  }
  public InstallPlanSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApproval(instance.getApproval()); 
    this.withApproved(instance.getApproved()); 
    this.withClusterServiceVersionNames(instance.getClusterServiceVersionNames()); 
    this.withGeneration(instance.getGeneration()); 
    this.withSource(instance.getSource()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec build() {
    InstallPlanSpec buildable = new InstallPlanSpec(fluent.getApproval(),fluent.getApproved(),fluent.getClusterServiceVersionNames(),fluent.getGeneration(),fluent.getSource(),fluent.getSourceNamespace());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    InstallPlanSpecBuilder that = (InstallPlanSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
